# Generated by Django 3.2.15 on 2022-09-22 16:56

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django_lifecycle.mixins
import pulpcore.app.models.access_policy
import pulpcore.app.models.fields
import pulpcore.app.models.upload
import pulpcore.app.util
import uuid



DEFAULT_DELETE_TRIGGER = """
CREATE OR REPLACE FUNCTION protect_default() RETURNS TRIGGER as $protect_default$
  BEGIN
    IF OLD.name = 'default' THEN
      RAISE EXCEPTION 'Cannot delete default Domain';
    END IF;
    RETURN OLD;
  END;
$protect_default$ LANGUAGE plpgsql;
CREATE TRIGGER protect_default BEFORE DELETE ON core_domain
  FOR EACH ROW EXECUTE FUNCTION protect_default();
"""

REMOVE_DEFAULT_DELETE_TRIGGER = """
DROP TRIGGER IF EXISTS protect_default ON core_domain;
DROP FUNCTION IF EXISTS protect_default();
"""

class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('core', '0100_upstreampulp'),
    ]

    operations = [
        migrations.CreateModel(
            name='Domain',
            fields=[
                ('pulp_id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('pulp_created', models.DateTimeField(auto_now_add=True)),
                ('pulp_last_updated', models.DateTimeField(auto_now=True, null=True)),
                ('name', models.SlugField(unique=True)),
                ('description', models.TextField(null=True)),
                ('storage_class', models.TextField()),
                ('storage_settings', pulpcore.app.models.fields.EncryptedJSONField(default=dict)),
                ('redirect_to_object_storage', models.BooleanField(default=True)),
                ('hide_guarded_distributions', models.BooleanField(default=False)),
            ],
            options={
                'permissions': [('manage_roles_domain', 'Can manage role assignments on domain')],
            },
            bases=(django_lifecycle.mixins.LifecycleModelMixin, models.Model, pulpcore.app.models.access_policy.AutoAddObjPermsMixin),
        ),
        migrations.RunSQL(DEFAULT_DELETE_TRIGGER, reverse_sql=REMOVE_DEFAULT_DELETE_TRIGGER),
    ]
